YouTube-Search
==============

*A lightweight tool written in Python to perform a Youtube search without actually using the YT API.*

:Author: Abhinav Anand

.. contents::
    :backlinks: none

.. sectnum::

What is it
---------------
`[back to top] <https://github.com/ab-anand/yt_search_api#Youtube-Search>`__

*A lightweight tool written in Python to perform a Youtube search without actually using the YT API.*